"""
This module provides utilities for processing databases, parsing sequences and checking different file or object formats.
"""

from ._checkers_and_helpers import (
    CustomYamlDumper,
    check_if_dna_sequence,
    check_if_key_exists,
    check_if_list,
    check_if_list_of_lists,
    check_tsv_format,
    generate_unique_filename,
)
from ._database_processor import (
    check_if_region_in_database,
    collapse_attributes_for_duplicated_sequences,
    format_oligo_attributes,
    merge_databases,
    flatten_attribute_list,
)
from ._sequence_parser import FastaParser, GffParser
from ._sequence_processor import (
    get_complement_regions,
    get_sequence_from_annotation,
    append_nucleotide_to_sequences,
)

__all__ = [
    "FastaParser",
    "GffParser",
    "CustomYamlDumper",
    "check_if_dna_sequence",
    "check_if_key_exists",
    "check_if_list",
    "check_if_list_of_lists",
    "check_tsv_format",
    "check_if_region_in_database",
    "generate_unique_filename",
    "collapse_attributes_for_duplicated_sequences",
    "format_oligo_attributes",
    "merge_databases",
    "flatten_attribute_list",
    "get_complement_regions",
    "get_sequence_from_annotation",
    "append_nucleotide_to_sequences",
]
